/**
 * Tree
*/

YAHOO.util.Event.on(window, "load", initializeTree);

/**
 * Search the document for UL elements with the correct CLASS name, then process them.
*/ 
function initializeTree()
{
	/***/
	setDefault("treeClass", "tree");
	setDefault("nodeClosedClass", "liClosed");
	setDefault("nodeOpenedClass", "liOpened");
	setDefault("nodeBulletClass", "liBullet");
	setDefault("nodeLinkedClass", "bullet");
	setDefault("preProcessTrees", true);
	/***/
	if ( preProcessTrees )
	{
		if ( !document.createElement )
		{
			return;
		}
		var uls = document.getElementsByTagName("ul");
		for ( var i = 0; i < uls.length; i++ )
		{
			var ul = uls[i];
			if ( ul.nodeName == "UL" && ul.className == "tree" )
			{
				processList(ul);
			}
		}
	}
	/*setCurrentTreeItem();*/
}

/**
 * utility function to set a global variable if it is not already set.
*/
function setDefault(name, value)
{
	if ( typeof(window[name]) == "undefined" || window[name] === null )
	{
		window[name] = value;
	}
}

/**
 *
*/
function setCurrentTreeItem(itemId)
{
	if ( !itemId )
	{
		itemId = "1";
	}
	expandToItem('menu', itemId);
	setColor('menu', itemId);
}

/**
 * Full expands a tree with a given ID.
*/
function expandTree(treeId)
{
	var ul = document.getElementById(treeId);
	if ( !ul )
	{
		return false;
	}
	expandCollapseList(ul, "liOpened");
}

/**
 * Fully collapses a tree with a given ID.
*/
function collapseTree(treeId)
{
	var ul = document.getElementById(treeId);
	if ( !ul )
	{
		return false;
	}
	expandCollapseList(ul, nodeClosedClass);
}

/**
 * Expands enough nodes to expose an LI with a given ID.
*/
function expandToItem(treeId, itemId)
{
	var ul = document.getElementById(treeId);
	if ( !ul )
	{
		return false;
	}
	var ret = expandCollapseList(ul, "liOpened", itemId);
	if ( ret )
	{
		var o = document.getElementById(itemId);
		if ( o.scrollIntoView )
		{
			o.scrollIntoView(false);
		}
	}
}

/**
 * Performs 3 functions:
 * a) Expand all nodes
 * b) Collapse all nodes
 * c) Expand all nodes to reach a certain ID
*/
function expandCollapseList(ul, cName, itemId)
{
	if ( !ul.childNodes || ul.childNodes.length === 0 )
	{
		return false;
	}
	// Iterate LIs
	for ( var itemi = 0; itemi < ul.childNodes.length; itemi++ )
	{
		var item = ul.childNodes[itemi];
		if ( itemId !== null && item.id == itemId )
		{
			return true;
		}
		if ( item.nodeName == "LI" )
		{
			var subLists = false;
			for ( var sitemi = 0; sitemi < item.childNodes.length; sitemi++ )
			{
				var sitem = item.childNodes[sitemi];
				if ( sitem.nodeName == "UL" )
				{
					subLists = true;
					var ret = expandCollapseList(sitem, cName, itemId);
					if ( itemId !== null && ret )
					{
						item.className = cName;
						return true;
					}
				}
			}
			if ( subLists && itemId === null )
			{
				item.className = cName;
			}
		}
	}
}



/**
 * Process a UL tag and all its children, to convert to a tree.
*/
function processList(ul)
{
	if ( !ul.childNodes || ul.childNodes.length === 0 )
	{
		return;
	}
	for ( var itemi = 0; itemi < ul.childNodes.length; itemi++ )
	{
		var item = ul.childNodes[itemi];
		item.className = nodeClosedClass;
		if ( item.nodeName == "LI" )
		{
			var subLists = false;
			for ( var sitemi = 0; sitemi < item.childNodes.length; sitemi++ )
			{
				var sitem = item.childNodes[sitemi];
				if ( sitem.nodeName == "SPAN" )
				{
					sitem.onclick = function()
					{
						if ( this.parentNode.className != nodeLinkedClass )
						{
							if ( this.parentNode.className == nodeClosedClass )
							{
								this.parentNode.className = nodeOpenedClass;
							}
						}
						return false;
					};
				}
				if ( sitem.nodeName == "UL" )
				{
					subLists = true;
					processList(sitem);
				}
			}
			var s= document.createElement("SPAN");
			var t= "\u00A0";
			s.className = nodeLinkedClass;
			if ( subLists )
			{
				if ( item.className === null || item.className === "" )
				{
					item.className = nodeClosedClass;
				}
				if ( item.firstChild.nodeName == "#text" )
				{
					t = t + item.firstChild.nodeValue;
					item.removeChild(item.firstChild);
				}
				s.onclick = function ()
				{
					this.parentNode.className = (this.parentNode.className == nodeOpenedClass) ? nodeClosedClass: nodeOpenedClass;
					return false;
				};
			}
			else
			{
				item.className = nodeBulletClass;
				s.onclick = function()
				{
					return false;
				};
			}
			s.appendChild(document.createTextNode(t));
			item.insertBefore(s, item.firstChild);
		}
	}
}

/**
 *
*/
function setColor(treeId, itemId)
{
	sp = document.getElementsByTagName("span");
	for ( var i = 0; i < sp.length; i++ )
	{
		var spl = sp[i];
		if ( itemId !== null && spl.id == itemId )
		{
			spl.style.backgroundColor = "#bfdbdb";
		}
		else
		{
			spl.style.backgroundColor = "transparent";
		}
	}
}